==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodIOChaosSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodIOChaosSpecFluentImpl<A extends PodIOChaosSpecFluent<A>> extends BaseFluent<A> implements PodIOChaosSpecFluent<A>{
  public PodIOChaosSpecFluentImpl() {
  }
  public PodIOChaosSpecFluentImpl(PodIOChaosSpec instance) {
    this.withActions(instance.getActions()); 
    this.withContainer(instance.getContainer()); 
    this.withVolumeMountPath(instance.getVolumeMountPath()); 
  }
  private ArrayList<IOChaosActionBuilder> actions = new ArrayList<IOChaosActionBuilder>();
  private String container;
  private String volumeMountPath;
  public A addToActions(Integer index,IOChaosAction item) {
    if (this.actions == null) {this.actions = new ArrayList<IOChaosActionBuilder>();}
    IOChaosActionBuilder builder = new IOChaosActionBuilder(item);_visitables.get("actions").add(index >= 0 ? index : _visitables.get("actions").size(), builder);this.actions.add(index >= 0 ? index : actions.size(), builder); return (A)this;
  }
  public A setToActions(Integer index,IOChaosAction item) {
    if (this.actions == null) {this.actions = new ArrayList<IOChaosActionBuilder>();}
    IOChaosActionBuilder builder = new IOChaosActionBuilder(item);
    if (index < 0 || index >= _visitables.get("actions").size()) { _visitables.get("actions").add(builder); } else { _visitables.get("actions").set(index, builder);}
    if (index < 0 || index >= actions.size()) { actions.add(builder); } else { actions.set(index, builder);}
     return (A)this;
  }
  public A addToActions(io.fabric8.chaosmesh.v1alpha1.IOChaosAction... items) {
    if (this.actions == null) {this.actions = new ArrayList<IOChaosActionBuilder>();}
    for (IOChaosAction item : items) {IOChaosActionBuilder builder = new IOChaosActionBuilder(item);_visitables.get("actions").add(builder);this.actions.add(builder);} return (A)this;
  }
  public A addAllToActions(Collection<IOChaosAction> items) {
    if (this.actions == null) {this.actions = new ArrayList<IOChaosActionBuilder>();}
    for (IOChaosAction item : items) {IOChaosActionBuilder builder = new IOChaosActionBuilder(item);_visitables.get("actions").add(builder);this.actions.add(builder);} return (A)this;
  }
  public A removeFromActions(io.fabric8.chaosmesh.v1alpha1.IOChaosAction... items) {
    for (IOChaosAction item : items) {IOChaosActionBuilder builder = new IOChaosActionBuilder(item);_visitables.get("actions").remove(builder);if (this.actions != null) {this.actions.remove(builder);}} return (A)this;
  }
  public A removeAllFromActions(Collection<IOChaosAction> items) {
    for (IOChaosAction item : items) {IOChaosActionBuilder builder = new IOChaosActionBuilder(item);_visitables.get("actions").remove(builder);if (this.actions != null) {this.actions.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromActions(Predicate<IOChaosActionBuilder> predicate) {
    if (actions == null) return (A) this;
    final Iterator<IOChaosActionBuilder> each = actions.iterator();
    final List visitables = _visitables.get("actions");
    while (each.hasNext()) {
      IOChaosActionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildActions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IOChaosAction> getActions() {
    return actions != null ? build(actions) : null;
  }
  public List<IOChaosAction> buildActions() {
    return actions != null ? build(actions) : null;
  }
  public IOChaosAction buildAction(Integer index) {
    return this.actions.get(index).build();
  }
  public IOChaosAction buildFirstAction() {
    return this.actions.get(0).build();
  }
  public IOChaosAction buildLastAction() {
    return this.actions.get(actions.size() - 1).build();
  }
  public IOChaosAction buildMatchingAction(Predicate<IOChaosActionBuilder> predicate) {
    for (IOChaosActionBuilder item: actions) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingAction(Predicate<IOChaosActionBuilder> predicate) {
    for (IOChaosActionBuilder item: actions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withActions(List<IOChaosAction> actions) {
    if (this.actions != null) { _visitables.get("actions").removeAll(this.actions);}
    if (actions != null) {this.actions = new ArrayList(); for (IOChaosAction item : actions){this.addToActions(item);}} else { this.actions = null;} return (A) this;
  }
  public A withActions(io.fabric8.chaosmesh.v1alpha1.IOChaosAction... actions) {
    if (this.actions != null) {this.actions.clear();}
    if (actions != null) {for (IOChaosAction item :actions){ this.addToActions(item);}} return (A) this;
  }
  public Boolean hasActions() {
    return actions != null && !actions.isEmpty();
  }
  public PodIOChaosSpecFluent.ActionsNested<A> addNewAction() {
    return new PodIOChaosSpecFluentImpl.ActionsNestedImpl();
  }
  public PodIOChaosSpecFluent.ActionsNested<A> addNewActionLike(IOChaosAction item) {
    return new PodIOChaosSpecFluentImpl.ActionsNestedImpl(-1, item);
  }
  public PodIOChaosSpecFluent.ActionsNested<A> setNewActionLike(Integer index,IOChaosAction item) {
    return new PodIOChaosSpecFluentImpl.ActionsNestedImpl(index, item);
  }
  public PodIOChaosSpecFluent.ActionsNested<A> editAction(Integer index) {
    if (actions.size() <= index) throw new RuntimeException("Can't edit actions. Index exceeds size.");
    return setNewActionLike(index, buildAction(index));
  }
  public PodIOChaosSpecFluent.ActionsNested<A> editFirstAction() {
    if (actions.size() == 0) throw new RuntimeException("Can't edit first actions. The list is empty.");
    return setNewActionLike(0, buildAction(0));
  }
  public PodIOChaosSpecFluent.ActionsNested<A> editLastAction() {
    int index = actions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last actions. The list is empty.");
    return setNewActionLike(index, buildAction(index));
  }
  public PodIOChaosSpecFluent.ActionsNested<A> editMatchingAction(Predicate<IOChaosActionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<actions.size();i++) { 
    if (predicate.test(actions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching actions. No match found.");
    return setNewActionLike(index, buildAction(index));
  }
  public String getContainer() {
    return this.container;
  }
  public A withContainer(String container) {
    this.container=container; return (A) this;
  }
  public Boolean hasContainer() {
    return this.container != null;
  }
  public String getVolumeMountPath() {
    return this.volumeMountPath;
  }
  public A withVolumeMountPath(String volumeMountPath) {
    this.volumeMountPath=volumeMountPath; return (A) this;
  }
  public Boolean hasVolumeMountPath() {
    return this.volumeMountPath != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodIOChaosSpecFluentImpl that = (PodIOChaosSpecFluentImpl) o;
    if (actions != null ? !actions.equals(that.actions) :that.actions != null) return false;
    if (container != null ? !container.equals(that.container) :that.container != null) return false;
    if (volumeMountPath != null ? !volumeMountPath.equals(that.volumeMountPath) :that.volumeMountPath != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(actions,  container,  volumeMountPath,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (actions != null && !actions.isEmpty()) { sb.append("actions:"); sb.append(actions + ","); }
    if (container != null) { sb.append("container:"); sb.append(container + ","); }
    if (volumeMountPath != null) { sb.append("volumeMountPath:"); sb.append(volumeMountPath); }
    sb.append("}");
    return sb.toString();
  }
  class ActionsNestedImpl<N> extends IOChaosActionFluentImpl<PodIOChaosSpecFluent.ActionsNested<N>> implements PodIOChaosSpecFluent.ActionsNested<N>,Nested<N>{
    ActionsNestedImpl(Integer index,IOChaosAction item) {
      this.index = index;
      this.builder = new IOChaosActionBuilder(this, item);
    }
    ActionsNestedImpl() {
      this.index = -1;
      this.builder = new IOChaosActionBuilder(this);
    }
    IOChaosActionBuilder builder;
    Integer index;
    public N and() {
      return (N) PodIOChaosSpecFluentImpl.this.setToActions(index,builder.build());
    }
    public N endAction() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodIOChaosSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodIOChaosSpecFluentImpl<A extends PodIOChaosSpecFluent<A>> extends BaseFluent<A> implements PodIOChaosSpecFluent<A>{
  public PodIOChaosSpecFluentImpl() {
  }
  public PodIOChaosSpecFluentImpl(PodIOChaosSpec instance) {
    if (instance != null) {
      this.withActions(instance.getActions());
      this.withContainer(instance.getContainer());
      this.withVolumeMountPath(instance.getVolumeMountPath());
    }
  }
  private ArrayList<IOChaosActionBuilder> actions = new ArrayList<IOChaosActionBuilder>();
  private String container;
  private String volumeMountPath;
  public A addToActions(int index,IOChaosAction item) {
    if (this.actions == null) {this.actions = new ArrayList<IOChaosActionBuilder>();}
    IOChaosActionBuilder builder = new IOChaosActionBuilder(item);
    if (index < 0 || index >= actions.size()) { _visitables.get("actions").add(builder); actions.add(builder); } else { _visitables.get("actions").add(index, builder); actions.add(index, builder);}
    return (A)this;
  }
  public A setToActions(int index,IOChaosAction item) {
    if (this.actions == null) {this.actions = new ArrayList<IOChaosActionBuilder>();}
    IOChaosActionBuilder builder = new IOChaosActionBuilder(item);
    if (index < 0 || index >= actions.size()) { _visitables.get("actions").add(builder); actions.add(builder); } else { _visitables.get("actions").set(index, builder); actions.set(index, builder);}
    return (A)this;
  }
  public A addToActions(io.fabric8.chaosmesh.v1alpha1.IOChaosAction... items) {
    if (this.actions == null) {this.actions = new ArrayList<IOChaosActionBuilder>();}
    for (IOChaosAction item : items) {IOChaosActionBuilder builder = new IOChaosActionBuilder(item);_visitables.get("actions").add(builder);this.actions.add(builder);} return (A)this;
  }
  public A addAllToActions(Collection<IOChaosAction> items) {
    if (this.actions == null) {this.actions = new ArrayList<IOChaosActionBuilder>();}
    for (IOChaosAction item : items) {IOChaosActionBuilder builder = new IOChaosActionBuilder(item);_visitables.get("actions").add(builder);this.actions.add(builder);} return (A)this;
  }
  public A removeFromActions(io.fabric8.chaosmesh.v1alpha1.IOChaosAction... items) {
    for (IOChaosAction item : items) {IOChaosActionBuilder builder = new IOChaosActionBuilder(item);_visitables.get("actions").remove(builder);if (this.actions != null) {this.actions.remove(builder);}} return (A)this;
  }
  public A removeAllFromActions(Collection<IOChaosAction> items) {
    for (IOChaosAction item : items) {IOChaosActionBuilder builder = new IOChaosActionBuilder(item);_visitables.get("actions").remove(builder);if (this.actions != null) {this.actions.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromActions(Predicate<IOChaosActionBuilder> predicate) {
    if (actions == null) return (A) this;
    final Iterator<IOChaosActionBuilder> each = actions.iterator();
    final List visitables = _visitables.get("actions");
    while (each.hasNext()) {
      IOChaosActionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildActions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IOChaosAction> getActions() {
    return actions != null ? build(actions) : null;
  }
  public List<IOChaosAction> buildActions() {
    return actions != null ? build(actions) : null;
  }
  public IOChaosAction buildAction(int index) {
    return this.actions.get(index).build();
  }
  public IOChaosAction buildFirstAction() {
    return this.actions.get(0).build();
  }
  public IOChaosAction buildLastAction() {
    return this.actions.get(actions.size() - 1).build();
  }
  public IOChaosAction buildMatchingAction(Predicate<IOChaosActionBuilder> predicate) {
    for (IOChaosActionBuilder item: actions) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingAction(Predicate<IOChaosActionBuilder> predicate) {
    for (IOChaosActionBuilder item: actions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withActions(List<IOChaosAction> actions) {
    if (this.actions != null) { _visitables.get("actions").clear();}
    if (actions != null) {this.actions = new ArrayList(); for (IOChaosAction item : actions){this.addToActions(item);}} else { this.actions = null;} return (A) this;
  }
  public A withActions(io.fabric8.chaosmesh.v1alpha1.IOChaosAction... actions) {
    if (this.actions != null) {this.actions.clear(); _visitables.remove("actions"); }
    if (actions != null) {for (IOChaosAction item :actions){ this.addToActions(item);}} return (A) this;
  }
  public Boolean hasActions() {
    return actions != null && !actions.isEmpty();
  }
  public PodIOChaosSpecFluentImpl.ActionsNested<A> addNewAction() {
    return new PodIOChaosSpecFluentImpl.ActionsNestedImpl();
  }
  public PodIOChaosSpecFluentImpl.ActionsNested<A> addNewActionLike(IOChaosAction item) {
    return new PodIOChaosSpecFluentImpl.ActionsNestedImpl(-1, item);
  }
  public PodIOChaosSpecFluentImpl.ActionsNested<A> setNewActionLike(int index,IOChaosAction item) {
    return new PodIOChaosSpecFluentImpl.ActionsNestedImpl(index, item);
  }
  public PodIOChaosSpecFluentImpl.ActionsNested<A> editAction(int index) {
    if (actions.size() <= index) throw new RuntimeException("Can't edit actions. Index exceeds size.");
    return setNewActionLike(index, buildAction(index));
  }
  public PodIOChaosSpecFluentImpl.ActionsNested<A> editFirstAction() {
    if (actions.size() == 0) throw new RuntimeException("Can't edit first actions. The list is empty.");
    return setNewActionLike(0, buildAction(0));
  }
  public PodIOChaosSpecFluentImpl.ActionsNested<A> editLastAction() {
    int index = actions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last actions. The list is empty.");
    return setNewActionLike(index, buildAction(index));
  }
  public PodIOChaosSpecFluentImpl.ActionsNested<A> editMatchingAction(Predicate<IOChaosActionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<actions.size();i++) { 
    if (predicate.test(actions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching actions. No match found.");
    return setNewActionLike(index, buildAction(index));
  }
  public String getContainer() {
    return this.container;
  }
  public A withContainer(String container) {
    this.container=container; return (A) this;
  }
  public Boolean hasContainer() {
    return this.container != null;
  }
  public String getVolumeMountPath() {
    return this.volumeMountPath;
  }
  public A withVolumeMountPath(String volumeMountPath) {
    this.volumeMountPath=volumeMountPath; return (A) this;
  }
  public Boolean hasVolumeMountPath() {
    return this.volumeMountPath != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodIOChaosSpecFluentImpl that = (PodIOChaosSpecFluentImpl) o;
    if (!java.util.Objects.equals(actions, that.actions)) return false;

    if (!java.util.Objects.equals(container, that.container)) return false;

    if (!java.util.Objects.equals(volumeMountPath, that.volumeMountPath)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(actions,  container,  volumeMountPath,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (actions != null) { sb.append("actions:"); sb.append(actions + ","); }
    if (container != null) { sb.append("container:"); sb.append(container + ","); }
    if (volumeMountPath != null) { sb.append("volumeMountPath:"); sb.append(volumeMountPath); }
    sb.append("}");
    return sb.toString();
  }
  class ActionsNestedImpl<N> extends IOChaosActionFluentImpl<PodIOChaosSpecFluentImpl.ActionsNested<N>> implements PodIOChaosSpecFluentImpl.ActionsNested<N>,Nested<N>{
    ActionsNestedImpl(int index,IOChaosAction item) {
      this.index = index;
      this.builder = new IOChaosActionBuilder(this, item);
    }
    ActionsNestedImpl() {
      this.index = -1;
      this.builder = new IOChaosActionBuilder(this);
    }
    IOChaosActionBuilder builder;
    int index;
    public N and() {
      return (N) PodIOChaosSpecFluentImpl.this.setToActions(index,builder.build());
    }
    public N endAction() {
      return and();
    }
    
  }
  
}
